==> linktocontent-5.x-1.0.tar.gz: linktocontent/tinymce_plugins/linktonode/jscripts/nodelist.js <==
// $Id: nodelist.js,v 1.1.2.3 2007/02/21 16:26:51 stborchert Exp $

var selectedNode = null;

function _fillNodelist(results) {
  if ((results == null) || (results.nodes == null) || (results.nodes == false))
    return;

  for (key in results.nodes) {
    _addNodeToList(results.nodes[key]);
  }
}

function _clearNodeList() {
  $("#nodelist tbody tr").each(
    function() {
      $(this).remove();
    }
  );
}

function selectRow(row) {
  if (!row) {
    return;
  }
  $('#nodelist tbody tr').each(function() { $(this).css('background', '#ffffff'); selectedNode = null; });
  selectedNode = row;
  $(row).css('background', '#dadfe9');
}

function _addNodeToList(node){
  var tr = $("<tr></tr>").appendTo("#nodelist tbody");
  tr.hover(
    function() {
      if (selectedNode != this) {
        $(this).css('background', '#cecece');
      }
    },
    function() {
      if (selectedNode != this) {
        $(this).css('background', '#ffffff');
      }
    }
  );
  tr.click(function() {
    selectRow(this);
  });

  var td = $("<td class=\"nid\">" + node.href + "</td>").appendTo(tr);

  $("<td>" + node.title + "</td>").appendTo(tr);
  $("<td>" + node.date + "</td>").appendTo(tr);
  $("<td>" + node.author + "</td>").appendTo(tr);
}

/**
 * make the nodelist accessible by keyboard
 **/
$('.accessible').keypress(function(e) {
  switch (e.keyCode) {
    case 39:
    case 40: // move selection down
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get(0);
      else
        selectedNode = $(selectedNode).next('tr').get(0);
      selectRow(selectedNode);
      break;
    case 37:
    case 38: // move selection up
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get($('#nodelist tbody tr').length - 1);
      else
        selectedNode = $(selectedNode).prev('tr').get(0);
      selectRow(selectedNode);
    break;
  }
});

==> linktocontent-5.x-1.3.tar.gz: linktocontent/tinymce_plugins/linktonode/jscripts/nodelist.js <==
// $Id: nodelist.js,v 1.1.2.4 2007/06/03 10:34:32 stborchert Exp $

var selectedNode = null;

function _fillNodelist(results) {
  if ((results == null) || (results.nodes == null) || (results.nodes == false))
    return;

  for (key in results.nodes) {
    _addNodeToList(results.nodes[key]);
  }
}

function _clearNodeList() {
  $('#nodelist tbody tr').each(
    function() {
      $(this).remove();
    }
  );
}

function selectRow(row) {
  if (!row) {
    return;
  }
  $('#nodelist tbody tr').each(function() { 
    $(this).css({background: '#ffffff'}); 
    selectedNode = null; 
  });
  selectedNode = row;
  $(row).css({background: '#dadfe9'});
}

function _addNodeToList(node){
  var tr = $('<tr></tr>').appendTo('#nodelist tbody');
  tr.hover(
    function() {
      if (selectedNode != this) {
        $(this).css({background: '#cecece'});
      }
    },
    function() {
      if (selectedNode != this) {
        $(this).css({background: '#ffffff'});
      }
    }
  );
  tr.click(function() {
    selectRow(this);
  });

  $('<td class="nid">' + node.href + '</td>').appendTo(tr);
  $('<td>' + node.title + '</td>').appendTo(tr);
  $('<td>' + node.date + '</td>').appendTo(tr);
  $('<td>' + node.author + '</td>').appendTo(tr);
}

/**
 * make the nodelist accessible by keyboard
 **/
$('.accessible').keypress(function(e) {
  switch (e.keyCode) {
    case 39:
    case 40: // move selection down
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get(0);
      else
        selectedNode = $(selectedNode).next('tr').get(0);
      selectRow(selectedNode);
      break;
    case 37:
    case 38: // move selection up
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get($('#nodelist tbody tr').length - 1);
      else
        selectedNode = $(selectedNode).prev('tr').get(0);
      selectRow(selectedNode);
    break;
  }
});
